scip: Mixed integer programming solver
======================================

Description
-----------

SCIP is currently one of the fastest open source mixed integer
programming (MIP) solvers. It is also a framework for constraint integer
programming and branch-cut-and-price. It allows total control of the
solution process and the access of detailed information down to the guts
of the solver.

License
-------

Apache 2.0


Upstream Contact
----------------

https://scipopt.org/#scipoptsuite


Dependencies
------------

scip brings its own patched version of the bliss library.
This will conflict with the optional package bliss.
